pro event_movie, times, outimg, data=data, $
   outsize=outsize, charsize=charsize, zbuff=zbuff, $
   goes=goes, femgrid=femgrid, color=color, twindow=twindow, $
   gcolor=gcolor, ncolor=ncolor, scolor=scolor, ticks=ticks, tcolor=tcolor, $
   default=default, summary=summary, status=status
;+
;   Name: event_movie
;
;   Purpose: form a 3D plot movie from UT events (via evt_grid)
;
;   Input Parameters:
;      times - event times (any Yohkoh/SOHO format)
;
;   Output Parameters:
;     outimg - movie cube of plots with events overlayed
;
;   Keyword Parameters:
;      goes - if set, use plot goes (time window around events)
;      charsize - if set, character size
;      color - color for event lines
;      gcolor - (goes only - goes grid color)
;      ncolor - (fem only - color for night/day )
;      scolor - (fem only - color for SAA)
;
;   Calling Sequence:
;      Two Primary Uses:
;         I.   IDL> utplot [any user utplot...]		; overlay on user plot
;	       IDL> event_movie,times
;
;        II.   IDL>event_movie,times, /goes 		; GOES overlay 
; 
;   History:
;      25-oct-1995 (SLF) - movie production
;       6-Nov-1995 (SLF) - cleaned up, defaults, ...
;      17-nov-1995 (SLF) - auto scale goes
;-

summary=keyword_set(summary)
default=keyword_set(default)
nt=n_elements(times)
dtemp=!d.name

tsecs= max(int2secarr(anytim2ints(times)))

if default then begin			; GOES plot in color (via linecolors.pro)
   zbuff=1
   goes=1
   color=2				; event line color
   tcolor=200				; tick color
   gcolor=10				; goes grid color
   if tsecs le 86400. then begin 	; overlay ephemeris if time <= 24 hours
      scolor=4				; SAA color
      ncolor=9				; Night color
   endif
endif 

plotgoes=keyword_set(goes)
femgrid=keyword_set(femgrid) or keyword_set(ncolor) or keyword_set(scolor)
ticks=keyword_set(ticks) or keyword_set(tcolor)
if not keyword_set(color) then color=150

if not keyword_set(twindow) then twindow=30      ; minutes

; overplots may be from existing window
isx=!d.name eq 'X' and !d.window ne -1
usex=isx and (1-plotgoes) 

if n_elements(outsize) eq 0 then begin
   if !d.name eq 'X' and !d.window ne -1 then $
      outsize=[!d.x_size,!d.y_size] else outsize=[256,128]
endif

outsize=long(outsize)
outimg=make_array(size=[3,outsize,nt,1,outsize(0)*outsize(1)*nt])

; save status
stemp=!p.charsize

zbuff=keyword_set(zbuff)
; user current X window?
if usex then begin
   savesys,/aplot
   xdat=tvrd()
endif else wdef,xx,outsize(0),outsize(1),zbuffer=zbuff

; if not supplied, scale character size according to Y size
if keyword_set(charsize) then csize=charsize else $
   charsize=.5  + ( (outsize(1)/128) * .1) < 2.

!p.charsize=charsize

set_plot,(['x','z'])(zbuff)

if default then begin
   tvlct,r0,g0,b0,/get
   linecolors
   tvlct,r1,g1,b1,/get   
   tvlct,[r0(0),r1(1:14),r0(15:*)], [g0(0),g1(1:14),g0(15:*)],[b0(0),b1(1:14),b0(15:*)]
endif

device,get_graphics=gtemp
device,set_graphics=3

status=1-plotgoes

case 1 of 
   usex: begin   
            tv,xdat 
            restsys,/aplot
   endcase

   plotgoes: begin
      plot_goes, status=status, $
      timegrid(times(0), min=-(twindow),/string), $
      timegrid(times(nt-1), min=twindow,/string),/xstyle, gcolor=gcolor, $
      five_minute=(tsecs gt 2.*86400.),/lo,color=([!p.color,5])(default)	; auto scale resolution
      endcase
   else: begin
         if keyword_set(data) then begin
	    utplot,times, data, psym=2, $
             title='SXT FLUX', color=color, /ynozero, $
	     yticks=5, ytickname=strarr(6)+' ', xmargin=[1,1]
	    
	 endif else $
            utplot,times,times.sxt.img_avg,psym=2, $
            title='SXT FLUX', color=color, $
	    yrange=[18,max(times.sxt.img_avg)], xmargin=[1,1]
   endcase
endcase

if not status then return		;*** unstructured exit, NO GOES data

; overlay Yohkoh ephemeris on request
if femgrid then fem_grid, /fillsaa, /fillnight, ncolor=ncolor, scolor=scolor

fname='event_' + str_replace(ex2fid(anytim2ex(times(0)),/sec),'.','_') + '_'

; overlay event TICKS on request
if n_elements(tcolor) eq 0 then tcolor=color
tcolor=200
if keyword_set(ticks) then evt_grid,times, color=tcolor, thick=2, $
   /quiet,tickpos=.8

; source XOR destination		; so movie "erases" previous line
device,set_graphics=6   

; for each event time...
if summary then nt=1
for i=0,nt-1 do begin
   evt_grid,times(i),lines=0, color=color,thick=2,/quiet           ; mark event
   if i ne 0 then $
   evt_grid,times(i-1),lines=0,color=color,thick=2,/quiet         ; erase last
   im=tvrd()                                               ; read image
   outimg(0,0,i)=im                                        ; fill movie
endfor

if summary then outimg=temporary(outimg(*,*,0))

; -----------  restore status ------------
!p.charsize=stemp
device,set_graphics=gtemp
set_plot,dtemp
; ----------------------------------------
return
end
